/* reset */
body,
button,
dd,
dl,
dt,
fieldset,
form,
h1,
h2,
h3,
h4,
h5,
h6,
input,
legend,
li,
ol,
p,
select,
table,
td,
textarea,
th,
ul {
  margin: 0;
  padding: 0;
}
h1,
h2,
h3,
h4,
h5,
h6 {
  font-size: inherit;
  line-height: inherit;
}
button,
input {
  -webkit-border-radius: 0;
  border-radius: 0;
  /* border: 0; */
}
button {
  background-color: transparent;
}
fieldset,
img {
  border: 0;
}
img {
  vertical-align: top;
}
ol,
ul {
  list-style: none;
}
address,
em {
  font-style: normal;
}
a {
  color: inherit;
  text-decoration: none;
}
a:hover {
  text-decoration: none;
}
iframe {
  overflow: hidden;
  margin: 0;
  border: 0;
  padding: 0;
  vertical-align: top;
}
mark {
  background-color: transparent;
}
i {
  font-style: normal;
}

/***** login *****/
#wrap {
  position: relative;
  display: flex;
  align-items: center;
  width: 100%;
  height: 100vh;
}
.join-wrap {
  width: 360px;
  margin: 0 auto;
}
.join-wrap .join-top {
  text-align: center;
}
.join-wrap .join-top h3 {
  font-size: 40px;
  font-weight: 500;
  line-height: 65px;
  margin: 0;
}
.join-wrap .join-top .txt {
  font-size: 17px;
  font-weight: bold;
}
.join-form {
  margin-top: 30px;
  padding: 5px 0;
}
.join-form .input-set:first-child {
  padding-bottom: 10px;
}
.join-form .input-set p {
  padding: 5px 0;
  font-size: 14px;
  font-weight: bold;
}
.join-form .input-set .input-box {
  position: relative;
  display: inline-flex;
  width: 360px;
  font-weight: 400;
  font-style: normal;
  color: rgba(0, 0, 0, 0.87);
}
.join-form .input-set .input-box input {
  width: 100%;
  padding: 9px 14px 9px 37px;
  font-weight: 500;
  background-color: #fff;
  border-radius: 4px;
  border: 1px solid rgba(34, 36, 38, 0.15);
  outline: none;
}
.join-form .input-set .input-box input::placeholder {
  color: #aeaeae;
}
.join-form .input-set .input-box i {
  position: absolute;
  left: 10px;
  top: 5px;
  font-size: 18px;
  color: #aeaeae;
}
.join-form .join-btn {
  display: inline-block;
  padding: 12px 0;
  margin-top: 10px;
  width: 100%;
  font-size: 17px;
  font-weight: 500;
  border: 0;
  border-radius: 4px;
  text-align: center;
  color: #fff;
  background: #2eaef8;
  cursor: pointer;
}
.login-img {
  display: block;
  content: " ";
  width: 225px;
  height: 78px;
  margin: 35px 0 30px 0;
  background: url(../images/logo.svg) no-repeat;
  background-size: 225px;
}
