export const config = {
  //baseUrl: 'http://localhost:5000/api/',
  //baseUrl: 'https://aivle-api-stg.moducoding.com/api/',
  baseUrl: 'https://aivle-api.moducoding.com/api/',
  chat: 'https://chat.codereet.com',
};
